pub struct UsageDetails {
pub input_token_count: Option<u64>,
pub output_token_count: Option<u64>,
pub total_token_count: Option<u64>,
pub cache_creation_input_token_count: Option<u64>,
pub cache_read_input_token_count: Option<u64>,
pub reasoning_output_token_count: Option<u64>,
pub additional_counts: HashMap<String, u64>,
}Expand description
Token usage counts for a request/response.
Supports element-wise addition to accumulate usage across streamed updates.
Fields
input_token_count: Option<u64>output_token_count: Option<u64>total_token_count: Option<u64>cache_creation_input_token_count: Option<u64>The number of input tokens written to a provider-managed cache.
cache_read_input_token_count: Option<u64>The number of input tokens served from a provider-managed cache.
reasoning_output_token_count: Option<u64>The number of output tokens used for reasoning.
additional_counts: HashMap<String, u64>Additional, provider-specific counts merged into the root on serialize.
Implementations
Sourceimpl UsageDetails
impl UsageDetails
pub fn new() -> UsageDetails
Sourcepub fn add_assign(&mut self, other: &UsageDetails)
pub fn add_assign(&mut self, other: &UsageDetails)
Element-wise add another usage into this one, treating None as 0
only when the other side has a value.