WorkflowExecutor

Struct WorkflowExecutor 

pub struct WorkflowExecutor { /* private fields */ }
An Executor that runs a child Workflow, enabling hierarchical composition.

Implementations

Source

impl WorkflowExecutor

pub fn new(id: impl Into<String>, workflow: Workflow) -> WorkflowExecutor

Wrap workflow as an executor with the given id.

By default the child’s outputs are sent onward as messages from this node. Use WorkflowExecutor::with_direct_output to instead yield them directly as parent workflow outputs.

pub fn with_direct_output(self, allow: bool) -> WorkflowExecutor

Yield the child’s outputs directly to the parent’s output stream instead of forwarding them as messages.

pub fn workflow(&self) -> &Workflow

The wrapped child workflow.